@@ -180,7 +180,8 @@ nm_fortisslvpn_ppp_service_new (NMConnection *connection, GError **error)
 	                                   "org.freedesktop.DBus",
 	                                   "/org/freedesktop/DBus",
 	                                   "org.freedesktop.DBus");
-	g_assert (proxy);
+	if (!proxy)
+		goto out;
 	success = dbus_g_proxy_call (proxy, "RequestName", error,
 	                             G_TYPE_STRING, NM_DBUS_SERVICE_FORTISSLVPN_PPP,
 	                             G_TYPE_UINT, 0,
@@ -198,8 +199,7 @@ nm_fortisslvpn_ppp_service_new (NMConnection *connection, GError **error)
 	 * plugin when it asks for them.
 	 */
 	if (!_service_cache_credentials (self, connection, error)) {
-		g_object_unref (self);
-		self = NULL;
+		g_clear_object (&self);
 		goto out;
 	}
 
@@ -326,6 +326,8 @@ static ValidProperty valid_properties[] = {
 	{ NM_FORTISSLVPN_KEY_USER,              G_TYPE_STRING, TRUE },
 	{ NM_FORTISSLVPN_KEY_CA,                G_TYPE_STRING, FALSE },
 	{ NM_FORTISSLVPN_KEY_TRUSTED_CERT,      G_TYPE_STRING, FALSE },
+	{ NM_FORTISSLVPN_KEY_CERT,              G_TYPE_STRING, FALSE },
+	{ NM_FORTISSLVPN_KEY_KEY,               G_TYPE_STRING, FALSE },
 	{ NM_FORTISSLVPN_KEY_PASSWORD"-flags",  G_TYPE_UINT, FALSE },
 	{ NULL,                                 G_TYPE_NONE, FALSE }
 };
@@ -674,6 +676,18 @@ run_openfortivpn (NMFortisslvpnPlugin *plugin, NMSettingVPN *s_vpn, GError **err
 		g_ptr_array_add (argv, (gpointer) g_strdup (value));
 	}
 
+	value = nm_setting_vpn_get_data_item (s_vpn, NM_FORTISSLVPN_KEY_CERT);
+	if (value) {
+		g_ptr_array_add (argv, (gpointer) g_strdup ("--user-cert"));
+		g_ptr_array_add (argv, (gpointer) g_strdup (value));
+	}
+
+	value = nm_setting_vpn_get_data_item (s_vpn, NM_FORTISSLVPN_KEY_KEY);
+	if (value) {
+		g_ptr_array_add (argv, (gpointer) g_strdup ("--user-key"));
+		g_ptr_array_add (argv, (gpointer) g_strdup (value));
+	}
+
 	value = nm_setting_vpn_get_data_item (s_vpn, NM_FORTISSLVPN_KEY_TRUSTED_CERT);
 	if (value) {
 		g_ptr_array_add (argv, (gpointer) g_strdup ("--trusted-cert"));
@@ -787,6 +801,8 @@ real_connect (NMVPNPlugin *plugin, NMConnection *connection, GError **error)
 	mode_t old_umask;
 	gchar *config;
 
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
 	s_vpn = NM_SETTING_VPN (nm_connection_get_setting (connection, NM_TYPE_SETTING_VPN));
 	g_assert (s_vpn);
 
